@@ -10,11 +10,11 @@ from mstrio.project_objects import (
 )
 from mstrio.connection import get_connection
 
-PROJECT_NAME = '<Project_name>'  # Insert project name here
-CUBE_ID = '<cube_id>'  # Insert name of cube on which you want to perform actions
-NODE_NAME = '<node_name>'  # Insert name of node on which you want to perform actions
-DB_CONNECTION_ID = '<database_connection_id>'  # insert ID of DB connection you want to include in your functions
-CUBE_CACHE_ID = '<cube_cache_id>'  #Insert ID of cube cache that you want to perform your actions upon
+PROJECT_NAME = $project_name  # Insert project name here
+CUBE_ID = $cube_id  # Insert name of cube on which you want to perform actions
+NODE_NAME = $node_name  # Insert name of node on which you want to perform actions
+DB_CONNECTION_ID = $db_connection_id  # insert ID of DB connection you want to include in your functions
+CUBE_CACHE_ID = $cube_cache_id  #Insert ID of cube cache that you want to perform your actions upon
 
 conn = get_connection(workstationData, project_name=PROJECT_NAME)
 
