@@ -12,14 +12,12 @@ from mstrio.project_objects import OlapCube, Report
 # get connection to an environment
 from mstrio.connection import get_connection
 
-PROJECT_NAME = '<Project_name>'  # Insert project name here
-CUBE_ID = "<Cube_ID>"
-REPORT_ID = "<Report_ID>"
-ATTRIBUTES_LIST = [
-    "<Attribute_ID>", "<Attribute_ID>"
-]  #Insert list of attributes that you want to include in  your functions
-METRICS_LIST = ["<Metric_ID>"]  # insert list of metrics to be used in your functions
-ATTRIBUTES_ELEMENTS_LIST = ["<Attribute_ID:Element_Name>", "<Attribute_ID:Element_Name>"]
+PROJECT_NAME = $project_name  # Insert project name here
+CUBE_ID = $cube_id
+REPORT_ID = $report_id
+ATTRIBUTES_LIST = $attributes_list  #Insert list of attributes that you want to include in  your functions
+METRICS_LIST = $metrics_list  # insert list of metrics to be used in your functions
+ATTRIBUTES_ELEMENTS_LIST = $attributes_elements_list
 
 conn = get_connection(workstationData, project_name=PROJECT_NAME)
 
