@@ -1,14 +1,14 @@
-from typing import TYPE_CHECKING
-
+from mstrio.connection import Connection
 from mstrio.utils.error_handlers import ErrorHandler
 
-if TYPE_CHECKING:
-    from mstrio.connection import Connection
-
 
 @ErrorHandler(err_msg='Error creating a new changeset.')
-def create_changeset(connection: "Connection", project_id: str = None, schema_edit: bool = False,
-                     error_msg: str = None):
+def create_changeset(
+    connection: "Connection",
+    project_id: str = None,
+    schema_edit: bool = False,
+    error_msg: str = None
+):
     """Create a new changeset for modelling manipulations."""
     if project_id is None:
         connection._validate_project_selected()
@@ -21,12 +21,14 @@ def create_changeset(connection: "Connection", project_id: str = None, schema_ed
 
 
 @ErrorHandler(err_msg='Error committing changeset {id} changes to the metadata.')
-def commit_changeset_changes(connection: "Connection", id: str, error_msg: str = None,
-                             throw_error=True):
+def commit_changeset_changes(
+    connection: "Connection", id: str, error_msg: str = None, throw_error=True
+):
     """Commit the changeset changes to metadata."""
     return connection.post(
         url=f"{connection.base_url}/api/model/changesets/{id}/commit",
-        headers={'X-MSTR-MSChanget': id}, params={'changesetId': id}
+        headers={'X-MSTR-MSChanget': id},
+        params={'changesetId': id}
     )
 
 
