@@ -1,7 +1,6 @@
 # flake8: noqa
-from .contact import *
-from .contact_group import *
 from .device import *
+from .event import Event, list_events
 from .schedule import *
 from .subscription import *
 from .transmitter import *
