@@ -1,4 +1,4 @@
-from typing import List, Optional, Union
+from typing import Optional, Union
 
 from packaging import version
 import pandas as pd
@@ -7,16 +7,23 @@ from tqdm.auto import tqdm
 
 from mstrio import config
 from mstrio.api import objects, reports
+from mstrio.api.schedules import get_contents_schedule
 from mstrio.connection import Connection
+from mstrio.distribution_services.schedule import Schedule
 from mstrio.object_management.search_operations import full_search, SearchPattern
 from mstrio.users_and_groups.user import User
+from mstrio.utils.cache import CacheSource, ContentCacheMixin
 from mstrio.utils.certified_info import CertifiedInfo
 from mstrio.utils.entity import (
-    CertifyMixin, CopyMixin, DeleteMixin, Entity, MoveMixin, ObjectTypes
+    CertifyMixin,
+    CopyMixin,
+    DeleteMixin,
+    Entity,
+    MoveMixin,
+    ObjectTypes
 )
 from mstrio.utils.filter import Filter
 from mstrio.utils.helper import (
-    deprecation_warning,
     exception_handler,
     fallback_on_timeout,
     get_parallel_number,
@@ -31,23 +38,23 @@ from mstrio.utils.sessions import FuturesSessionWithRenewal
 def list_reports(
     connection: Connection,
     name: Optional[str] = None,
-    name_begins: Optional[str] = None,
     search_pattern: Union[SearchPattern, int] = SearchPattern.CONTAINS,
     project_id: Optional[str] = None,
     project_name: Optional[str] = None,
     to_dictionary: bool = False,
     limit: Optional[int] = None,
+    folder_id: Optional[str] = None,
     **filters,
-) -> Union[List["Report"], List[dict]]:
+) -> Union[list["Report"], list[dict]]:
     """Get list of Report objects or dicts with them.
     Optionally filter reports by specifying 'name'.
 
     Optionally use `to_dictionary` to choose output format.
 
-    Wildcards available for 'name_begins':
+    Wildcards available for 'name':
         ? - any character
         * - 0 or more of any characters
-        e.g. name_begins = ?onny will return Sonny and Tonny
+        e.g. name = ?onny will return Sonny and Tonny
 
     Specify either `project_id` or `project_name`.
     When `project_id` is provided (not `None`), `project_name` is omitted.
@@ -61,7 +68,6 @@ def list_reports(
             `connection.Connection()`
         name (string, optional): value the search pattern is set to, which
             will be applied to the names of reports being searched
-        name_begins (string, optional): deprecated. Use `name` instead.
         to_dictionary (bool, optional): If True returns dict, by default (False)
             returns Report objects
         search_pattern (SearchPattern enum or int, optional): pattern to search
@@ -72,6 +78,8 @@ def list_reports(
         project_name (string, optional): Project name
         limit (integer, optional): limit the number of elements returned. If
             None all object are returned.
+        folder_id (string, optional): ID of a folder where the search
+            will be performed. Defaults to None.
         **filters: Available filter parameters: ['id', 'name', 'type',
             'subtype', 'date_created', 'date_modified', 'version', 'owner',
             'ext_type', 'view_media', 'certified_info']
@@ -86,14 +94,6 @@ def list_reports(
         with_fallback=False if project_name else True,
     )
 
-    if name_begins:
-        deprecation_warning(
-            "`name_begins`",
-            "`name`",
-            "11.3.7.101",  # NOSONAR
-            False
-        )
-        name, search_pattern = name_begins, SearchPattern.BEGIN_WITH
     objects_ = full_search(
         connection,
         object_types=ObjectTypes.REPORT_DEFINITION,
@@ -101,6 +101,7 @@ def list_reports(
         name=name,
         pattern=search_pattern,
         limit=limit,
+        root=folder_id,
         **filters,
     )
     if to_dictionary:
@@ -108,7 +109,7 @@ def list_reports(
     return [Report.from_dict(obj_, connection) for obj_ in objects_]
 
 
-class Report(Entity, CertifyMixin, CopyMixin, MoveMixin, DeleteMixin):
+class Report(Entity, CertifyMixin, CopyMixin, MoveMixin, DeleteMixin, ContentCacheMixin):
     """Access, filter, publish, and extract data from in-memory reports.
 
     Create a Report object to load basic information on a report dataset.
@@ -116,6 +117,9 @@ class Report(Entity, CertifyMixin, CopyMixin, MoveMixin, DeleteMixin):
     `Report.clear_filters()`. Fetch dataset through `Report.to_dataframe()`
     method.
 
+    _CACHE_TYPE is a variable used by ContentCache class for cache filtering
+    purposes.
+
     Attributes:
         connection: MicroStrategy connection object returned by
             `connection.Connection()`.
@@ -148,13 +152,14 @@ class Report(Entity, CertifyMixin, CopyMixin, MoveMixin, DeleteMixin):
         acl: Object access control list
     """
     _OBJECT_TYPE = ObjectTypes.REPORT_DEFINITION
+    _CACHE_TYPE = CacheSource.Type.REPORT
     _FROM_DICT_MAP = {
         **Entity._FROM_DICT_MAP,
         'owner': User.from_dict,
         'certified_info': CertifiedInfo.from_dict,
     }
     _SIZE_LIMIT = 10000000  # this sets desired chunk size in bytes
-    _DELETE_NONE_VALUES_RECURSION = False
+
     _API_PATCH: dict = {**Entity._API_PATCH, ('folder_id'): (objects.update_object, 'partial_put')}
 
     def __init__(
@@ -324,7 +329,7 @@ class Report(Entity, CertifyMixin, CopyMixin, MoveMixin, DeleteMixin):
 
                 # logical OR for filtered attribute elements
                 for attribute in attr_dict:
-                    attr_name = list(filter(lambda x: x['id'] in attribute,
+                    attr_name = list(filter(lambda x, attr=attribute: x['id'] in attr,
                                             self.attributes))[0]['name']
                     elements = attr_dict[attribute]
                     indexes = indexes | self._dataframe[attr_name].isin(elements)
@@ -679,6 +684,32 @@ class Report(Entity, CertifyMixin, CopyMixin, MoveMixin, DeleteMixin):
         }
         return {key: attributes[key] for key in sorted(attributes, key=sort_object_properties)}
 
+    def list_available_schedules(
+        self,
+        to_dictionary: bool = False
+    ) -> list["Schedule"] | list[dict]:
+        """Get a list of schedules available for the report.
+
+        Args:
+            to_dictionary (bool, optional): If True returns a list of
+                dictionaries, otherwise returns a list of Schedules.
+                False by default.
+
+        Returns:
+            List of Schedule objects or list of dictionaries.
+        """
+        schedules_list_response = get_contents_schedule(
+            connection=self.connection,
+            project_id=self.connection.project_id,
+            body={'id': self.id, 'type': 'report'}
+        ).json().get('schedules')
+        if to_dictionary:
+            return schedules_list_response
+        return [
+            Schedule.from_dict(connection=self.connection, source=schedule_id)
+            for schedule_id in schedules_list_response
+        ]
+
     @property
     def attributes(self):
         if not self.__definition_retrieved:
